@@ -11,11 +11,11 @@ class CommandError(Exception):
 class CommandBase:
     help = '...'
 
-    def __init__(self, runner_path: str):
+    def __init__(self, root: str):
         self.stdin, self.stdout, self.stderr = sys.stdin, sys.stdout, sys.stderr
 
+        self.root = root
         self.name = self.__module__.split('.')[-1]
-        self.runner_path = runner_path
         self.logger = Logger('management', f'{self.name}: ', self.stdout)
 
     def add_arguments(self, parser: ArgumentParser):
@@ -24,9 +24,8 @@ class CommandBase:
     def run(self, args):
         parser = ArgumentParser(description=self.help)
         self.add_arguments(parser)
-        args = vars(parser.parse_args(args))
         try:
-            self.handle(**args)
+            self.handle(**vars(parser.parse_args(args)))
         except KeyboardInterrupt:
             sys.stderr.write(f'Commad interrupted...\n')
         except CommandError as e:
