@@ -2,7 +2,7 @@ import datetime
 import decimal
 import json
 import uuid
-from json import JSONDecodeError, JSONDecoder  # noqa
+from json import JSONDecodeError, JSONDecoder
 from typing import Any, IO, Type, Union
 
 import frozendict
@@ -24,9 +24,18 @@ except ImportError:
     pass
 
 try:
-    from pydantic import BaseModel
+    try:
+        from pydantic.v1 import BaseModel
 
-    compat_transforms[BaseModel] = lambda o: o.dict()
+        compat_transforms[BaseModel] = lambda o: o.dict()
+
+        from pydantic import BaseModel
+
+        compat_transforms[BaseModel] = lambda o: o.model_dump()
+    except ImportError:
+        from pydantic import BaseModel
+
+        compat_transforms[BaseModel] = lambda o: o.dict()
 except ImportError:
     pass
 
